import { useState } from "react";
import { Button, Col } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faLock, faLockOpen } from "@fortawesome/free-solid-svg-icons";


function BoatTile(props: any) {
    const { t } = useTranslation();
    const [hover, setMouseHover] = useState<boolean>(false);

    return (
        <Col>
            <div className={`card-body shadow position-relative mb-1 rounded-2 ${props.isInUse ? (props.overdue ? 'bg-danger' : 'bg-secondary') : (props.blocked ? 'bg-info' : 'bg-success')} boatTile`}
                onClick={props.clickEvent} style={{ height: "90px" }}>
                <div className="text-uppercase fs-4 tile-label-boatName position-absolute ms-2 mt-1 top-0 start-0 text-white fw-bold"
                    style={{ maxWidth: "98%", overflow: "hidden", textOverflow: "ellipsis", whiteSpace: "nowrap" }}>{props.boatName}</div>
                <div className="tile-label-time position-absolute me-2 mt-2 top-0 end-0 text-white">{props.time}</div>
                <div className="tile-label-persons position-absolute ms-2 mb-2 bottom-0 start-0 text-white">{props.persons}</div>
                {/* Conditonally render the overdue text if it is set*/}
                {props.overdue &&
                    <div className="tile-label-overdue position-absolute me-2 mb-2 bottom-0 end-0 text-white fw-bold">Overdue!</div>
                }
                {props.blocked &&
                    <div className="tile-label-overdue position-absolute me-2 mb-2 bottom-0 end-0 text-white fw-bold">
                        <div className="mx-2" onMouseOver={() => { setMouseHover(true) }} onMouseLeave={() => { setMouseHover(false) }} onClick={(event) => { /*props.unblock;*/ event.stopPropagation() }}>
                            <FontAwesomeIcon icon={hover ? faLockOpen : faLock} className={`${hover ? 'text-primary' : 'text-danger'} changeIcon`} size="2x" />
                        </div>
                    </div>
                }
                {!props.isInUse && !props.blocked &&
                    <div className="tile-label-overdue position-absolute me-2 mb-2 bottom-0 end-0 text-white fw-bold">
                        <div className="mx-2" onMouseOver={() => { setMouseHover(true) }} onMouseLeave={() => { setMouseHover(false) }} onClick={(event) => { /*props.unblock;*/ event.stopPropagation() }}>
                            <FontAwesomeIcon icon={hover ? faLock : faLockOpen} className={`${hover ? 'text-danger' : 'text-primary'} changeIcon`} size="2x" />
                        </div>
                    </div>
                }
            </div>
        </Col>

    );
}

export default BoatTile;
